@@ -4,6 +4,15 @@ errors and exceptions
 
 from werkzeug.exceptions import HTTPException
 
+def _patch_werkzeug():
+    import pkg_resources
+    if pkg_resources.get_distribution("werkzeug").version < "0.9":
+        # sorry, for touching your internals :).
+        import werkzeug._internal
+        werkzeug._internal.HTTP_STATUS_CODES[429] = 'Too Many Requests'
+
+_patch_werkzeug()
+del _patch_werkzeug
 
 class ConfigurationError(Exception):
     """
